@@ -17,7 +17,8 @@ class Config(MaitaiClient):
     config_dir = os.path.expanduser(os.environ.get("MAITAI_CONFIG_DIR", "~/.maitai"))
     refresh_timer = None
 
-    def __init__(self):
+    def __init__(self, api_key=None):
+        super().__init__()
         self._api_key = None
         self._company_id = None
         self.websocket_listener_thread = None
@@ -31,11 +32,18 @@ class Config(MaitaiClient):
             cerebras_api_key=Key(id=-1, key_value=os.environ.get("CEREBRAS_API_KEY")),
             sambanova_api_key=Key(id=-1, key_value=os.environ.get("SAMBANOVA_API_KEY")),
             gemini_api_key=Key(id=-1, key_value=os.environ.get("GEMINI_API_KEY")),
+            azure_api_key=Key(id=-1, key_value=os.environ.get("AZURE_API_KEY")),
+            deepseek_api_key=Key(id=-1, key_value=os.environ.get("DEEPSEEK_API_KEY")),
         )
         self.refresh_interval = 30 * 60  # 30 minutes in seconds
+        if api_key:
+            self.initialize(api_key)
+
+    def __del__(self):
+        self.cleanup()
 
     @property
-    def api_key(self):
+    def api_key(self) -> str:
         if self._api_key is None:
             if self.initialized:
                 raise ValueError(
@@ -48,10 +56,11 @@ class Config(MaitaiClient):
                         "Maitai API Key has not been set. Either pass it directly into the client, or by setting the environment variable MAITAI_API_KEY."
                     )
                 self.initialize(api_key=api_key)
+                self._api_key = api_key
         return self._api_key
 
     @api_key.setter
-    def api_key(self, value):
+    def api_key(self, value: str):
         self._api_key = value
 
     def refresh_applications(self):
@@ -65,6 +74,18 @@ class Config(MaitaiClient):
         if not self._company_id:
             raise Exception("Company ID not found in response")
 
+        # Process API keys from the response
+        if "api_keys" in response_json:
+            api_keys = response_json["api_keys"]
+            # Update Groq API key if provided
+            for key_name, key_value in api_keys.items():
+                if key_value and hasattr(self.auth_keys, f"{key_name}_api_key"):
+                    setattr(
+                        self.auth_keys,
+                        f"{key_name}_api_key",
+                        Key(id=-1, key_value=key_value),
+                    )
+
         self.store_application_metadata(applications)
 
     def initialize(self, api_key, retry=0):
@@ -175,10 +196,3 @@ class Config(MaitaiClient):
             self.refresh_timer.cancel()
             self.refresh_timer = None
         self.initialized = False
-
-
-config = Config()
-
-import atexit
-
-atexit.register(config.cleanup)
