@@ -1,6 +1,7 @@
 import os
 
-if os.environ.get("MAITAI_ENV") in ["prod", "staging", "development"]:
+
+if os.environ.get("MAITAI_ENV") in ["prod", "staging", "development", "test"]:
     from maitai_models.config import Config, InferenceLocations
 else:
     from maitai.models.config import Config, InferenceLocations
